# -*- coding: utf-8 -*-
# Generated by Django 1.10.5 on 2017-01-05 22:12
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('epic', '0004_auto_20150918_2111'),
    ]

    operations = [
        migrations.AlterField(
            model_name='datasheet',
            name='ds_file',
            field=models.FileField(upload_to=b'epic/datasheets', verbose_name=b'Datasheet File'),
        ),
    ]
